==> haskell-text-zipper-0.10.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-zipper
version: 0.10.1
id: text-zipper-0.10.1-JvbVA7IqHNX8Kekk6p0W86
key: text-zipper-0.10.1-JvbVA7IqHNX8Kekk6p0W86
license: BSD3
copyright: (c) 2015 Jonathan Daugherty
maintainer: cygnus@foobox.com
homepage: https://github.com/jtdaugherty/text-zipper/
synopsis: A text editor zipper library
description:
    This library provides a zipper and API for editing text.
category: Text
author: Jonathan Daugherty <cygnus@foobox.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words
hidden-modules: Data.Text.Zipper.Vector
abi: c887d39a19efcd3db4d811c8614dab92
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-zipper-0.10.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-zipper-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/text-zipper-0.10.1
hs-libraries: HStext-zipper-0.10.1-JvbVA7IqHNX8Kekk6p0W86
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html: /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-zipper-0.10.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-zipper
version: 0.10.1
id: text-zipper-0.10.1-BW4gHNsbDkd5o3B01HvX20
key: text-zipper-0.10.1-BW4gHNsbDkd5o3B01HvX20
license: BSD3
copyright: (c) 2015 Jonathan Daugherty
maintainer: cygnus@foobox.com
homepage: https://github.com/jtdaugherty/text-zipper/
synopsis: A text editor zipper library
description:
    This library provides a zipper and API for editing text.
category: Text
author: Jonathan Daugherty <cygnus@foobox.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words
hidden-modules: Data.Text.Zipper.Vector
abi: 6625defed6dd1caa64683fff9007ff87
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-zipper-0.10.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-zipper-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/text-zipper-0.10.1
hs-libraries: HStext-zipper-0.10.1-BW4gHNsbDkd5o3B01HvX20
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html: /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
